Skip to contents

This class represents an interaction feature for IQ models, inheriting from IQFeature.

This method defines how an IQInteraction object should be displayed.

Usage

# S4 method for class 'IQInteraction'
show(object)

Arguments

object

An IQInteraction object

Slots

name

The name of the IQ interaction feature (character).

coefs

The coefficients of the IQ interaction feature (numeric).

term1

The name of the first term in the interaction (character).

term2

The name of the second term in the interaction (character).

term1_type

The type of the first term (motif, additional, etc.).

term2_type

The type of the second term (motif, additional, etc.).

scale

Numeric scaling factor applied during trajectory model training.

inter_max

The maximum value of the raw interaction (term1 * term2) used for normalization.

norm_min

The minimum value used in the norm01 transformation.

norm_max

The maximum value used in the norm01 transformation.