Skip to contents

This function creates IQSeqFeature objects for all possible dinucleotides and GC content.

Usage

create_dinuc_features(
  traj_model,
  quantile = 0.95,
  size = NULL,
  dinucleotides = c("AA", "AC", "AG", "AT", "CA", "CC", "CG", "CT", "GA", "GC", "GG",
    "GT", "TA", "TC", "TG", "TT"),
  feat_names = dinucleotides,
  include_gc = TRUE,
  add_compute_func = TRUE
)

Arguments

traj_model

A trajectory model object.

quantile

The quantile to use for normalization (default is 0.95).

size

The size of the sequences to use for feature computation.

dinucleotides

A vector of dinucleotides to create features for (default is all possible dinucleotides).

feat_names

A vector of feature names to use for each dinucleotide (default is the dinucleotide itself).

include_gc

Logical indicating whether to include GC content feature (default is TRUE).

add_compute_func

Logical indicating whether to add a compute function to each IQSeqFeature object (default is TRUE).

Value

A list of IQSeqFeature objects, one for each dinucleotide and GC content if included.