Compute all features or responses required by an IQModel
iq_model.compute_features.RdThis function computes features or feature responses for an IQModel based on the provided inputs.
Usage
iq_model.compute_features(
model,
sequences = NULL,
intervals = NULL,
new_data = NULL,
return_responses = FALSE,
return_separate = FALSE,
normalize_energies = TRUE
)Arguments
- model
An IQModel object
- sequences
Optional vector of DNA sequences
- intervals
Optional data frame of genomic intervals
- new_data
Optional data frame of pre-computed features
- return_responses
Logical indicating whether to return responses (TRUE) or raw features (FALSE)
- return_separate
Logical indicating whether to return separate data frames
- normalize_energies
Logical indicating whether to normalize PBM energies