Skip to contents

This function computes all interaction features for a given dataset.

Usage

iq_model.compute_interactions(model, feature_data)

Arguments

model

An IQmodel object

feature_data

A data frame containing feature values needed for interactions

Value

A data frame containing computed interaction values