Skip to contents

A precomputed matrix of motif energy quantiles for the mouse gastrulation dataset, used for fast normalization of motif energies without requiring access to normalization intervals.

Usage

mouse_db_quantiles

Format

A matrix where rows are motifs and columns are quantile values.

See also

compute_motif_energies for usage with the db_quantiles parameter

Examples

data(mouse_db_quantiles)
dim(mouse_db_quantiles)
#> [1] 21862    21