Convert a list of PBM objects to a motif database
pbm_list_to_mdb.RdThis function converts a list of PBM objects to a motif database format compatible with prego::extract_pwm.

pbm_list_to_mdb.RdThis function converts a list of PBM objects to a motif database format compatible with prego::extract_pwm.