Skip to contents

This function takes a trajectory model with interactions and converts them to a list of IQ interaction features.

Usage

traj_model_interactions_to_iq_feature_list(traj_model)

Arguments

traj_model

The trajectory model object to convert.

Value

A list of IQ interaction features, where each feature contains the interaction name and its corresponding coefficients.