IQInteraction class
IQInteraction-class.RdThis class represents an interaction feature for IQ models, inheriting from IQFeature.
This method defines how an IQInteraction object should be displayed.
Slots
nameThe name of the IQ interaction feature (character).
coefsThe coefficients of the IQ interaction feature (numeric).
term1The name of the first term in the interaction (character).
term2The name of the second term in the interaction (character).
term1_typeThe type of the first term (motif, additional, etc.).
term2_typeThe type of the second term (motif, additional, etc.).
scaleNumeric scaling factor applied during trajectory model training.
inter_maxThe maximum value of the raw interaction (term1 * term2) used for normalization.
norm_minThe minimum value used in the norm01 transformation.
norm_maxThe maximum value used in the norm01 transformation.