Convert trajectory model interactions to IQ feature list
traj_model_interactions_to_iq_feature_list.RdThis function takes a trajectory model with interactions and converts them to a list of IQ interaction features.

traj_model_interactions_to_iq_feature_list.RdThis function takes a trajectory model with interactions and converts them to a list of IQ interaction features.